Stan Math Library: boost Namespace Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

Namespaces
boost Namespace Reference

Reimplementing boost functionality. More...

## Namespaces
| math
| Reimplmeneting boost functionality for `stan::math::var` and and bugs in classification of integer types.

## Detailed Description

Reimplementing boost functionality.

[ Stan Home Page ] © 2011–2016, Stan Development Team.